package com.ruoyi.zongzhi.service;

import java.util.List;
import com.ruoyi.zongzhi.domain.TcNetworkSentiment;

/**
 * 网络舆情Service接口
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
public interface ITcNetworkSentimentService 
{
    /**
     * 查询网络舆情
     * 
     * @param id 网络舆情主键
     * @return 网络舆情
     */
    public TcNetworkSentiment selectTcNetworkSentimentById(Long id);

    /**
     * 查询网络舆情列表
     * 
     * @param tcNetworkSentiment 网络舆情
     * @return 网络舆情集合
     */
    public List<TcNetworkSentiment> selectTcNetworkSentimentList(TcNetworkSentiment tcNetworkSentiment);

    /**
     * 新增网络舆情
     * 
     * @param tcNetworkSentiment 网络舆情
     * @return 结果
     */
    public int insertTcNetworkSentiment(TcNetworkSentiment tcNetworkSentiment);

    /**
     * 修改网络舆情
     * 
     * @param tcNetworkSentiment 网络舆情
     * @return 结果
     */
    public int updateTcNetworkSentiment(TcNetworkSentiment tcNetworkSentiment);

    /**
     * 批量删除网络舆情
     * 
     * @param ids 需要删除的网络舆情主键集合
     * @return 结果
     */
    public int deleteTcNetworkSentimentByIds(Long[] ids);

    /**
     * 删除网络舆情信息
     * 
     * @param id 网络舆情主键
     * @return 结果
     */
    public int deleteTcNetworkSentimentById(Long id);
}
